from freeGPTFix import *
import requests
__author__ = "RedPiar"
__Name__ = "freeGPTFix"
__version__ = "1.0.5"

url = f"https://pypi.org/pypi/{__Name__}/json"
	
response = requests.get(url)
	
if response.status_code == 200:
	data = response.json()
		
	version = data['info']['version']
if version != __version__:
	print(f"[freeGPTFix] Your version {__version__}, New version {version}")


"""
freeGPT's pollinations module
"""

from requests import get
from requests.exceptions import RequestException
from random import randint


class Generation:
    """
    This class provides methods for generating images based on prompts.
    """

    def create(self, prompt):
        """
        Create a new image generation based on the given prompt.

        Args:
            prompt (str): The prompt for generating the image.

        Returns:
            resp: The generated image content
        """
        try:
            return get(
                url=f"https://image.pollinations.ai/prompt/{prompt}{randint(1, 10000)}",
                timeout=30,
            ).content
        except RequestException as exc:
            raise RequestException("Unable to fetch the response.") from exc



"""
freeGPT's gpt3.5 module
"""

from requests import post
from requests.exceptions import RequestException
from uuid import uuid4

class Completion:
	"""
	This class provides methods for generating completions based on prompts.
	"""

	def create(self, prompt):
		"""
		Create a completion for the given prompt using an AI text generation API.

		Args:
			prompt (str): The input prompt for generating the text.

		Returns:
			str: The generated text as a response from the API.

		Raises:
			requests.exceptions.RequestException: If there is an issue with sending the request or fetching the response.
		"""
		try:
			res = post("https://chatgpt5free.com/wp-json/mwai-ui/v1/chats/submit",
				headers={"authority": "chatgpt5free.com",
					"path": "/wp-json/mwai-ui/v1/chats/submit",
					"scheme": "https",
					"accept": "*/*",
					"accept-encoding": "gzip, deflate, br",
					"accept-language": "ru-RU,ru;q=0.9,en-US;q=0.8,en;q=0.7",
					"content-type": "application/json",
					"cookie": "_ga=GA1.1.1164364256.1723035611; __gsas=ID=93ce1eeabe6a3665:T=1723035614:RT=1723035614:S=ALNI_Mau1GaFql56MGuxlIO5Yof9i8pI6g; mwai_session_id=66b36ffcc662a; __gads=ID=8d91d54792d96acd:T=1723035606:RT=1723036111:S=ALNI_MZCxKWpk6ZJUMznYW4bBfKuO_uN3Q; __gpi=UID=00000e877ca7d791:T=1723035606:RT=1723036111:S=ALNI_MbNN8EV4pRoai1NEQqccyo_RKFPGw; __eoi=ID=6cf36da3fa62ad5b:T=1723035606:RT=1723036111:S=AA-Afjbmu2Be1uiS8CL7W0zlmpaj; _ga_WQV20EPC74=GS1.1.1723035610.1.1.1723036199.0.0.0",
					"origin": "https://chatgpt5free.com",
					"referer": "https://chatgpt5free.com/chatgpt-5-free/",
					"sec-ch-ua": "\"Not_A Brand\";v=\"99\", \"Google Chrome\";v=\"109\", \"Chromium\";v=\"109\"",
					"sec-ch-ua-mobile": "?0",
					"sec-ch-ua-platform": "Windows",
					"sec-fetch-dest": "empty",
					"sec-fetch-mode": "cors",
					"sec-fetch-site": "same-origin",
					"user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/109.0.0.0 Safari/537.36",
					"x-wp-nonce": "a901745329"
				},
				json={
					"botId":"default",
					"customId":None,
					"session":"N/A",
					"chatId":str(uuid4()),
					"newMessage":prompt,
					"newFileId":None,
					"stream":False})
			return res.json()
		except RequestException as exc:
			raise RequestException("Unable to fetch the response.") from exc


import requests
from uuid import uuid4
from re import findall, sub

class Completion:
    """
    This class provides methods for generating completions based on prompts.
    """

    def create(self, prompt):
        """
        Generate a completion based on the provided prompt.

        Args:
            prompt (str): The input prompt to generate a completion from.

        Returns:
            str: The generated completion as a text string.

        Raises:
            Exception: If the response does not contain the expected "youChatToken".
        """
        try:
            response = requests.get(
                "https://you.com/api/streamingSearch",
                headers={
                    "cache-control": "no-cache",
                    "referer": "https://you.com/search?q=gpt4&tbm=youchat",
                    "cookie": f"safesearch_guest=Off; uuid_guest={str(uuid4())}",
                    "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/107.0.0.0 Safari/537.36"
                },
                params={
                    "q": prompt,
                    "page": 1,
                    "count": 10,
                    "safeSearch": "Off",
                    "onShoppingPage": False,
                    "mkt": "",
                    "responseFilter": "WebPages,Translations,TimeZone,Computation,RelatedSearches",
                    "domain": "youchat",
                    "queryTraceId": str(uuid4()),
                    "chat": [],
                },
            )
            if "youChatToken" not in response.text:
                raise Exception("Unable to fetch the response.")

            token = (
                "".join(
                    findall(
                        r"{\"youChatToken\": \"(.*?)\"}",
                        response.text
                    )
                )
                .replace("\\n", "\n")
                .replace("\\\\", "\\")
                .replace('\\"', '"')
            )
            decoded_string = token.encode('utf-8').decode('unicode_escape')
            text = sub(r'[#*]', '', decoded_string)
            return text
        
        except requests.RequestException as e:
            print("Request Error:", e)
            raise
        except Exception as e:
            print("General Error:", e)
            raise


"""
freeGPT's gpt3 module
"""

from requests import post
from requests.exceptions import RequestException


class Completion:
	"""
	This class provides methods for generating completions based on prompts.
	"""

	def create(self, prompt):
		"""
		Create a completion for the given prompt using an AI text generation API.

		Args:
			prompt (str): The input prompt for generating the text.

		Returns:
			str: The generated text as a response from the API.

		Raises:
			requests.exceptions.RequestException: If there is an issue with sending the request or fetching the response.
		"""
		try:
			resp = post(
				url="https://api.binjie.fun/api/generateStream",
				headers={
  "authority": "api.binjie.fun",
  "method": "POST",
  "path": "/api/generateStream",
  "scheme": "https",
  "accept": "application/json, text/plain, */*",
  "accept-encoding": "gzip, deflate, br",
  "accept-language": "ru-RU,ru;q=0.9,en-US;q=0.8,en;q=0.7",
  "content-type": "application/json",
  "origin": "https://chat18.aichatos8.com",
  "referer": "https://chat18.aichatos8.com/",
  "sec-ch-ua": "\"Not_A Brand\";v=\"99\", \"Google Chrome\";v=\"109\", \"Chromium\";v=\"109\"",
  "sec-ch-ua-mobile": "?0",
  "sec-ch-ua-platform": "Windows",
  "sec-fetch-dest": "empty",
  "sec-fetch-mode": "cors",
  "sec-fetch-site": "cross-site",
  "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/109.0.0.0 Safari/537.36"
},
				json={
					"prompt": prompt,
					"withoutContext": True,
					"stream": False,
				},
			)
			resp.encoding = "utf-8"
			return resp.text
		except RequestException as exc:
			raise RequestException("Unable to fetch the response.") from exc


from setuptools import setup, find_packages

with open("README.md", encoding="utf-8") as f:
    README = f.read()
setup(
    name="freeGPTFix",
    version="1.0.5",
    author_email="Redpiar.official@gmail.com",
    description="freeGPT provides free access to text and image generation models.",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/RedPiarOfficial/FreeGPTFix",
    author="RedPiar",
    license="MIT",
    keywords=[
        "artificial-intelligence",
        "machine-learning",
        "deep-learning",
        "gpt4free",
        "gpt4all",
        "freegpt",
        "chatgpt",
        "python",
        "llama",
        "llm",
        "nlp",
        "gpt",
        "ai",
    ],
    python_requires=">=3.8",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        "requests"
    ],
    project_urls={
        "Source": "https://github.com/RedPiarOfficial/FreeGPTFix",
    },
)
